##  Step 5: Clean Up Your Workspace
Follow these steps:
  1. Review any unlinked IT components related to the “Decision Intelligence & Automation“ tech category. Manually create a relation to one of the new tech categories.
  2. Archive the “Platform“ tech category fact sheet.
  3. Ensure there are no relations to IT components from the “Decision Intelligence & Automation“ tech category fact sheet, then archive it.


YesNo
Send
